package cd.casic.pipeline.dispatch.api;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.dispatch.pojo.JobQuotaSystem;
import cd.casic.pipeline.dispatch.pojo.enums.JobQuotaVmType;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

@Tag(name = "OP_JOBS_SYSTEM_QUOTA", description = "Job默认配额管理")
@RestController
@RequestMapping("/op/jobs/system/quota")
public interface OpJobQuotaSystemResource {

    @Operation(summary = "统计已运行的配额信息")
    @GetMapping("/all/statistics")
    CommonResult<Map<String, Object>> statistics(
    @Parameter(description = "分页大小", required = false)
    @RequestParam("limit") Integer limit,
    @Parameter(description = "偏移", required = false)
    @RequestParam("offset") Integer offset
    );

    @Operation(summary = "获取全部的JOB配额信息")
    @GetMapping("/all/list")
    CommonResult<java.util.List<JobQuotaSystem>> list();

    @Operation(summary = "获取系统默认JOB配额信息")
    @GetMapping("/{jobQuotaVmType}")
    CommonResult<java.util.List<JobQuotaSystem>> get(
    @Parameter(description = "构建机类型", required = false)
    @PathVariable("jobQuotaVmType") JobQuotaVmType jobQuotaVmType,
    @Parameter(description = "构建来源", required = false)
    @RequestParam("channelCode") String channelCode
    );

    @Operation(summary = "添加系统默认JOB配额信息")
    @PutMapping("/")
    CommonResult<Boolean> add(
    @Parameter(description = "Job配额信息", required = true)
    JobQuotaSystem jobQuota
    );

    @Operation(summary = "删除系统默认JOB配额信息")
    @DeleteMapping("/{jobQuotaVmType}")
    CommonResult<Boolean> delete(
    @Parameter(description = "构建机类型", required = true)
    @PathVariable("jobQuotaVmType") JobQuotaVmType jobQuotaVmType,
    @Parameter(description = "构建来源", required = false)
    @RequestParam("channelCode") String channelCode
    );

    @Operation(summary = "更新系统的JOB配额信息")
    @PostMapping("/{jobQuotaVmType}")
    CommonResult<Boolean> update(
    @Parameter(description = "构建机类型", required = true)
    @PathVariable("jobQuotaVmType") JobQuotaVmType jobQuotaVmType,
    @Parameter(description = "Job配额信息", required = true)
    JobQuotaSystem jobQuota
    );

    @Operation(summary = "清零当月已运行时间")
    @PostMapping("/clear/vm/{vmType}")
    CommonResult<Boolean> restore(
    @Parameter(description = "构建机类型", required = true)
    @PathVariable("vmType") JobQuotaVmType vmType
    );
}