package cd.casic.ci.process.api.engine;

import cd.casic.ci.common.pipeline.pojo.ErrorInfo;
import cd.casic.ci.common.pipeline.pojo.JobHeartbeatRequest;
import cd.casic.ci.process.api.engine.pojo.HeartBeatInfo;
import cd.casic.ci.process.api.process.pojo.BuildJobResult;
import cd.casic.ci.process.api.process.pojo.BuildTask;
import cd.casic.ci.process.api.process.pojo.BuildTaskResult;
import cd.casic.ci.process.api.process.pojo.BuildVariables;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import kotlin.Result;
import org.springframework.web.bind.annotation.*;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.*;

/**
 * @author by mianbin
 * @Classname BuildJobResource
 * @Description TODO
 * @Date 2025/3/31 15:20
 */
@Tag(name = "ENGINE_BUILD_JOB", description = "引擎-构建机请求|此接口不接受服务间Feign，只接受构建机处请求")
@RestController
@RequestMapping("/build/worker")
public interface BuildJobResource {

    @Operation(summary = "构建机器启动成功")
    @PutMapping("/started")
    Result<BuildVariables> jobStarted(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "构建ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_BUILD_ID) String buildId,
            @Parameter(description = "构建环境ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_VM_SEQ_ID) String vmSeqId,
            @Parameter(description = "构建机名称", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_VM_NAME) String vmName,
            @Parameter(description = "网络问题导致的重试次数", required = false)
            @RequestParam(value = "retryCount", required = false) String retryCount
    );

    @Operation(summary = "构建机请求获取任务")
    @GetMapping("/claim")
    Result<BuildTask> claimTask(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "构建ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_BUILD_ID) String buildId,
            @Parameter(description = "构建环境ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_VM_SEQ_ID) String vmSeqId,
            @Parameter(description = "构建机名称", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_VM_NAME) String vmName
    );

    @Operation(summary = "构建机Job完成任务")
    @PostMapping("/complete")
    Result<Boolean> completeTask(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "构建ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_BUILD_ID) String buildId,
            @Parameter(description = "构建环境ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_VM_SEQ_ID) String vmSeqId,
            @Parameter(description = "构建机名称", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_VM_NAME) String vmName,
            @Parameter(description = "执行结果", required = true)
            @RequestBody BuildTaskResult result
    );

    @Operation(summary = "结束构建机Job")
    @PostMapping("/end")
    Result<Boolean> jobEnd(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "构建ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_BUILD_ID) String buildId,
            @Parameter(description = "构建环境ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_VM_SEQ_ID) String vmSeqId,
            @Parameter(description = "构建机名称", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_VM_NAME) String vmName,
            @Parameter(description = "执行结果", required = false)
            @RequestBody(required = false) BuildJobResult result
    );

    @Operation(summary = "Job超时触发")
    @PostMapping("/timeout")
    Result<Boolean> jobTimeout(
            @Parameter(description = "projectId", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "pipelineId", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PIPELINE_ID) String pipelineId,
            @Parameter(description = "构建ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_BUILD_ID) String buildId,
            @Parameter(description = "构建环境ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_VM_SEQ_ID) String vmSeqId
    );

    @Operation(summary = "Job心跳请求")
    @PostMapping("/heartbeat")
    Result<Boolean> jobHeartbeat(
            @Parameter(description = "构建ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_BUILD_ID) String buildId,
            @Parameter(description = "构建环境ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_VM_SEQ_ID) String vmSeqId,
            @Parameter(description = "构建机名称", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_VM_NAME) String vmName
    );

    @Operation(summary = "Job心跳请求V1版")
    @PostMapping("/heartbeat/v1")
    Result<HeartBeatInfo> jobHeartbeatV1(
            @Parameter(description = "projectId", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "构建ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_BUILD_ID) String buildId,
            @Parameter(description = "构建环境ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_VM_SEQ_ID) String vmSeqId,
            @Parameter(description = "构建机名称", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_VM_NAME) String vmName,
            @Parameter(description = "执行次数", required = false)
            @RequestParam(value = "executeCount", required = false) Integer executeCount,
            @Parameter(description = "心跳请求报文体", required = false)
            @RequestBody(required = false) JobHeartbeatRequest jobHeartbeatRequest
    );

    @Operation(summary = "job异常上报并停止构建") // #5046 增加启动时异常上报，并停止构建，如果网络通的话
    @PostMapping("/submit_error")
    Result<Boolean> submitError(
            @Parameter(description = "projectId", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "pipelineId", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PIPELINE_ID) String pipelineId,
            @Parameter(description = "构建ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_BUILD_ID) String buildId,
            @Parameter(description = "构建环境ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_VM_SEQ_ID) String vmSeqId,
            @Parameter(description = "执行结果", required = true)
            @RequestBody ErrorInfo errorInfo
    );

    @Operation(summary = "获取当前构建的构建详情页")
    @GetMapping("/detail_url")
    Result<String> getBuildDetailUrl(
            @Parameter(description = "projectId", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID) String projectId,
            @Parameter(description = "pipelineId", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PIPELINE_ID) String pipelineId,
            @Parameter(description = "构建ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_BUILD_ID) String buildId
    );
}
