package cd.casic.ci.process.engine.worker;


import cd.casic.ci.process.constant.CommandConstant;
import cd.casic.ci.process.engine.enums.ContextStateEnum;
import cd.casic.ci.process.engine.manager.RunContextManager;
import cd.casic.ci.process.engine.runContext.BaseRunContext;

import cd.casic.ci.process.engine.runContext.TaskRunContext;
import cd.casic.ci.process.enums.MachineSystemEnum;
import cd.casic.ci.process.process.dataObject.machine.MachineInfo;
import cd.casic.ci.process.process.service.machine.MachineInfoService;

import cd.casic.ci.process.ssh.SshClient;
import cd.casic.ci.process.ssh.SshClientFactory;
import cd.casic.ci.process.ssh.WinRMHelper;
import jakarta.annotation.Resource;

import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;

import java.util.Arrays;
import java.util.List;


@Data
@Slf4j
public abstract class BaseWorker implements Runnable{
    // 一些属性
    @Resource
    private RunContextManager contextManager;
    private String contextKey;
    @Resource
    public MachineInfoService machineInfoService;

    @Override
    public void run() {
        if (StringUtils.isEmpty(contextKey)) {
            log.error("请设置当前worker的contextKey");
            return;
        }
        doWorker(contextKey);
    }

    public void doWorker(String contextKey){
        BaseRunContext context = contextManager.getContext(contextKey);
        if (context instanceof TaskRunContext taskRunContext){
            try {
                taskRunContext.changeContextState(ContextStateEnum.READY);
                taskRunContext.changeContextState(ContextStateEnum.RUNNING);
                execute(taskRunContext);
            } catch (Exception e) {
                taskRunContext.changeContextState(ContextStateEnum.BAD_ENDING);
                return;
            }
            // TODO 执行结束修改context的state,并且通知父类
            taskRunContext.changeContextState(ContextStateEnum.HAPPY_ENDING);
        }
    }
    public abstract void execute(TaskRunContext context);

}
