package cd.casic.pipeline.store.api.container;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.store.pojo.container.BuildResource;
import cd.casic.pipeline.store.pojo.container.BuildResourceRequest;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "OP_PIPELINE_BUILD_RESOURCE", description = "OP-流水线-构建资源")
@RestController
@RequestMapping("/op/pipeline/build/resource")
public interface OpBuildResourceResource {

    @Operation(summary = "添加流水线构建资源信息")
    @PostMapping("/")
    CommonResult<Boolean> add(
            @Parameter(description = "流水线构建资源请求体", required = true)
            BuildResourceRequest buildResourceRequest
    );

    @Operation(summary = "更新流水线构建资源信息")
    @PutMapping("/{id}")
    CommonResult<Boolean> update(
            @Parameter(description = "流水线构建资源ID", required = true)
            @PathVariable("id")
            String id,
            @Parameter(description = "流水线构建资源请求体", required = true)
            BuildResourceRequest buildResourceRequest
    );

    @Operation(summary = "获取所有流水线构建资源信息")
    @GetMapping("/")
    CommonResult<List<BuildResource>> listAllPipelineBuildResources();

    @Operation(summary = "根据ID获取流水线构建资源信息")
    @GetMapping("/{id}")
    CommonResult<BuildResource> getPipelineBuildResourceById(
            @Parameter(description = "流水线构建资源ID", required = true)
            @PathVariable("id")
            String id
    );

    @Operation(summary = "根据ID获取流水线构建资源信息")
    @DeleteMapping("/{id}")
    CommonResult<Boolean> deletePipelineBuildResourceById(
            @Parameter(description = "流水线构建资源ID", required = true)
            @PathVariable("id")
            String id
    );
}