package cd.casic.pipeline.store.api.template;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.store.pojo.common.publication.StoreProcessInfo;
import cd.casic.pipeline.store.pojo.template.MarketTemplateRelRequest;
import cd.casic.pipeline.store.pojo.template.MarketTemplateUpdateRequest;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.AUTH_HEADER_USER_ID;

@Tag(name = "USER_MARKET_TEMPLATE", description = "模板")
@RestController
@RequestMapping("/user/market")
public interface UserTemplateReleaseResource {

    @Operation(summary = "关联模板")
    @PostMapping("/templates/{templateCode}/store/rel")
    CommonResult<Boolean> addMarketTemplate(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "模板代码", required = true)
            @PathVariable("templateCode")
            String templateCode,
            @Parameter(description = "关联模板请求报文体", required = true)
            MarketTemplateRelRequest marketTemplateRelRequest
    );

    @Operation(summary = "上架模板")
    @PutMapping("/desk/template/release")
    CommonResult<String> updateMarketTemplate(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "上架模板请求报文体", required = true)
            MarketTemplateUpdateRequest marketTemplateUpdateRequest
    );

    @Operation(summary = "根据模板版本ID获取模板版本进度")
    @GetMapping("/desk/template/release/process/{templateId}")
    CommonResult<StoreProcessInfo> getProcessInfo(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "templateId", required = true)
            @PathVariable("templateId")
            String templateId
    );

    @Operation(summary = "取消发布")
    @PutMapping("/desk/template/release/cancel/templateIds/{templateId}")
    CommonResult<Boolean> cancelRelease(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "templateId", required = true)
            @PathVariable("templateId")
            String templateId
    );

    @Operation(summary = "下架模板")
    @PutMapping("/desk/template/offline/templateCodes/{templateCode}/versions")
    CommonResult<Boolean> offlineTemplate(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "模版代码", required = true)
            @PathVariable("templateCode")
            String templateCode,
            @Parameter(description = "版本号", required = false)
            @RequestParam("version")
            String version,
            @Parameter(description = "原因", required = false)
            @RequestParam("reason")
            String reason
    );
}